@@ -385,13 +385,13 @@ class Sf:
         elif ~record_dataframe.columns.isin(field_metadata[object_api]).all():
             # checks whether any of the columns in the dataframe passed in are not valid field API names
             raise RequiredValuesNotProvidedDuringUpdate(message="One of the columns in the record dataframe is not a valid field for the object")
-        elif record_dataframe.columns.drop('Id').isin(field_metadata[field_metadata['Updateable'] == False]['Account']).any():
+        elif record_dataframe.columns.isin(field_metadata[(field_metadata['Updateable'] == False) & (field_metadata[object_api] != "Id")][object_api]).any():
             # checks whether any of the columns in the dataframe passed in are not updateable
-            non_updatable_fields = list(set(record_dataframe.columns) - set(field_metadata[field_metadata['Updateable'] == True]['Account']))
+            non_updatable_fields = list(set(record_dataframe.columns) - set(field_metadata[(field_metadata['Updateable'] == True) | (field_metadata[object_api] == "Id")][object_api]))
             raise RequiredValuesNotProvidedDuringUpdate(message=f"The following fields are not updatable: {', '.join(non_updatable_fields)}")
-        elif record_dataframe.columns.isin(field_metadata[(~field_metadata['Compoundfieldname'].isnull()) & (field_metadata['Compoundfieldname'] != 'Name')]['Account']).any():
+        elif record_dataframe.columns.isin(field_metadata[(~field_metadata['Compoundfieldname'].isnull()) & (field_metadata['Compoundfieldname'] != 'Name')][object_api]).any():
             # checks whether any of the columns in the dataframe passed in are compound fields
-            compound_fields = list(set(record_dataframe.columns) & set(field_metadata[(~field_metadata['Compoundfieldname'].isnull()) & (field_metadata['Compoundfieldname'] != 'Name')]['Account']))
+            compound_fields = list(set(record_dataframe.columns) & set(field_metadata[(~field_metadata['Compoundfieldname'].isnull()) & (field_metadata['Compoundfieldname'] != 'Name')][object_api]))
             raise RequiredValuesNotProvidedDuringUpdate(message=f"The following fields are compound fields, which are not updatable: {', '.join(compound_fields)}")
         # checks whether an reference (lookup/master-detail) field is included in the source dataframe
         #  or ~record_dataframe.columns.isin(field_metadata[field_metadata['Type'] == 'reference'][object_api]).any()
@@ -441,13 +441,13 @@ class Sf:
             raise RequiredValuesNotProvidedDuringUpdate(message="One of the columns in the record dataframe is not a valid field for the object")
         elif external_id_field_api == "":
             raise RequiredValuesNotProvidedDuringUpsert(message="External ID field API is required")
-        elif record_dataframe.columns.drop('Id').isin(field_metadata[field_metadata['Updateable'] == False]['Account']).any():
+        elif record_dataframe.columns.isin(field_metadata[(field_metadata['Updateable'] == False) & (field_metadata[object_api] != "Id")][object_api]).any():
             # checks whether any of the columns in the dataframe passed in are not updateable
-            non_updatable_fields = list(set(record_dataframe.columns) - set(field_metadata[field_metadata['Updateable'] == True]['Account']))
+            non_updatable_fields = list(set(record_dataframe.columns) - set(field_metadata[(field_metadata['Updateable'] == True) | (field_metadata[object_api] == "Id")][object_api]))
             raise RequiredValuesNotProvidedDuringUpdate(message=f"The following fields are not updatable: {', '.join(non_updatable_fields)}")
-        elif record_dataframe.columns.isin(field_metadata[(~field_metadata['Compoundfieldname'].isnull()) & (field_metadata['Compoundfieldname'] != 'Name')]['Account']).any():
+        elif record_dataframe.columns.isin(field_metadata[(~field_metadata['Compoundfieldname'].isnull()) & (field_metadata['Compoundfieldname'] != 'Name')][object_api]).any():
             # checks whether any of the columns in the dataframe passed in are compound fields
-            compound_fields = list(set(record_dataframe.columns) & set(field_metadata[(~field_metadata['Compoundfieldname'].isnull()) & (field_metadata['Compoundfieldname'] != 'Name')]['Account']))
+            compound_fields = list(set(record_dataframe.columns) & set(field_metadata[(~field_metadata['Compoundfieldname'].isnull()) & (field_metadata['Compoundfieldname'] != 'Name')][object_api]))
             raise RequiredValuesNotProvidedDuringUpdate(message=f"The following fields are compound fields, which are not updatable: {', '.join(compound_fields)}")
         else:
             record_dataframe.replace(np.nan, None, inplace=True)
